@@ -2,7 +2,7 @@ import os
 import unittest
 import json
 import logging
-from kinnaird_utils.files import read_yaml_file
+from kinnaird_utils.file_utils import read_yaml_file
 
 logger = logging.getLogger(__name__)
 
